<?php
/**
 * Custom Functions.
 *
 * @package NewsRepublic
 */
if( !function_exists('newsrepublic_cat_selected') ):

    // Category Select on list after search
    function newsrepublic_cat_selected( $cat_nicename ) {

        $q_var = get_query_var( 'category' );

        if ( $q_var === $cat_nicename ) {

            return esc_attr('selected="selected"');
        }

        return false;
    }

endif;

if( !function_exists( 'newsrepublic_fonts_url' ) ) :

    //Google Fonts URL
    function newsrepublic_fonts_url(){

        $font_families = array(
            'Roboto:ital,wght@0,400;0,500;0,700;1,400;1,500;1,700',
            'Abril+Fatface',
        );

        $fonts_url = add_query_arg( array(
            'family' => implode( '&family=', $font_families ),
            'display' => 'swap',
        ), 'https://fonts.googleapis.com/css2' );

        return esc_url_raw($fonts_url);
    }

endif;

if( !function_exists( 'newsrepublic_sanitize_sidebar_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function newsrepublic_sanitize_sidebar_option_meta( $input ){

        $metabox_options = array( 'global-sidebar','left-sidebar','right-sidebar','no-sidebar' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }
    }

endif;

if( !function_exists( 'newsrepublic_page_lists' ) ) :

    // Page List.
    function newsrepublic_page_lists(){

        $page_lists = array();
        $page_lists[''] = esc_html__( '-- Select Page --','newsrepublic' );
        $pages = get_pages(
            array (
                'parent'  => 0, // replaces 'depth' => 1,
            )
        );
        foreach( $pages as $page ){

            $page_lists[$page->ID] = $page->post_title;

        }
        return $page_lists;
    }

endif;

if( !function_exists( 'newsrepublic_sanitize_post_layout_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function newsrepublic_sanitize_post_layout_option_meta( $input ){

        $metabox_options = array( 'global-layout','layout-1','layout-2' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }

    }

endif;

if( !function_exists( 'newsrepublic_sanitize_header_overlay_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function newsrepublic_sanitize_header_overlay_option_meta( $input ){

        $metabox_options = array( 'global-layout','enable-overlay' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }

    }

endif;

/**
 * NewsRepublic SVG Icon helper functions
 *
 * @package NewsRepublic
 * @since 1.0.0
 */
if ( ! function_exists( 'newsrepublic_theme_svg' ) ):
    /**
     * Output and Get Theme SVG.
     * Output and get the SVG markup for an icon in the Newsrepublic_SVG_Icons class.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function newsrepublic_theme_svg( $svg_name, $return = false ) {

        if( $return ){

            return newsrepublic_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in newsrepublic_get_theme_svg();.

        }else{

            echo newsrepublic_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in newsrepublic_get_theme_svg();.
            
        }
    }

endif;

if ( ! function_exists( 'newsrepublic_get_theme_svg' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function newsrepublic_get_theme_svg( $svg_name ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            Newsrepublic_SVG_Icons::get_svg( $svg_name ),
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );
        if ( ! $svg ) {
            return false;
        }
        return $svg;

    }

endif;

if ( ! function_exists( 'newsrepublic_svg_escape' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function newsrepublic_svg_escape( $input ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            $input,
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );

        if ( ! $svg ) {
            return false;
        }

        return $svg;

    }

endif;

if( !function_exists('newsrepublic_post_format_icon') ):

    // Post Format Icon.
    function newsrepublic_post_format_icon( $format ){

        if( $format == 'video' ){
            $icon = newsrepublic_get_theme_svg( 'video' );
        }elseif( $format == 'audio' ){
            $icon = newsrepublic_get_theme_svg( 'audio' );
        }elseif( $format == 'gallery' ){
            $icon = newsrepublic_get_theme_svg( 'gallery' );
        }elseif( $format == 'quote' ){
            $icon = newsrepublic_get_theme_svg( 'quote' );
        }elseif( $format == 'image' ){
            $icon = newsrepublic_get_theme_svg( 'image' );
        }else{
            $icon = '';
        }

        return $icon;
    }

endif;

if( !function_exists( 'newsrepublic_social_menu_icon' ) ) :

    function newsrepublic_social_menu_icon( $item_output, $item, $depth, $args ) {

        // Add Icon
        if ( isset( $args->theme_location ) && 'newsrepublic-social-menu' === $args->theme_location ) {

            $svg = Newsrepublic_SVG_Icons::get_theme_svg_name( $item->url );

            if ( empty( $svg ) ) {
                $svg = newsrepublic_theme_svg( 'link',$return = true );
            }

            $item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
        }

        return $item_output;
    }
    
endif;

add_filter( 'walker_nav_menu_start_el', 'newsrepublic_social_menu_icon', 10, 4 );

if ( ! function_exists( 'newsrepublic_sub_menu_toggle_button' ) ) :

    function newsrepublic_sub_menu_toggle_button( $args, $item, $depth ) {

        // Add sub menu toggles to the main menu with toggles
        if ( $args->theme_location == 'newsrepublic-primary-menu' && isset( $args->show_toggles ) ) {
            // Wrap the menu item link contents in a div, used for positioning
            $args->before = '<div class="submenu-wrapper">';
            $args->after  = '';
            // Add a toggle to items with children
            if ( in_array( 'menu-item-has-children', $item->classes ) ) {
                $toggle_target_string = '.menu-item.menu-item-' . $item->ID . ' > .sub-menu';
                // Add the sub menu toggle
                $args->after .= '<button type="button" class="theme-aria-button submenu-toggle" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250" aria-expanded="false"><span class="btn__content" tabindex="-1"><span class="screen-reader-text">' . __( 'Show sub menu', 'newsrepublic' ) . '</span>' . newsrepublic_get_theme_svg( 'chevron-down' ) . '</span></button>';
            }
            // Close the wrapper
            $args->after .= '</div><!-- .submenu-wrapper -->';
            // Add sub menu icons to the main menu without toggles (the fallback menu)
        } elseif ( $args->theme_location == 'newsrepublic-primary-menu' ) {
            if ( in_array( 'menu-item-has-children', $item->classes ) ) {
                $args->before = '<div class="link-icon-wrapper">';
                $args->after  = newsrepublic_get_theme_svg( 'chevron-down' ) . '</div>';
            } else {
                $args->before = '';
                $args->after  = '';
            }
        }
        return $args;

    }

    add_filter( 'nav_menu_item_args', 'newsrepublic_sub_menu_toggle_button', 10, 3 );

endif;


if( !function_exists( 'newsrepublic_post_category_list' ) ) :

    // Post Category List.
    function newsrepublic_post_category_list( $select_cat = true ){

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $post_cat_cat_array = array();
        if( $select_cat ){

            $post_cat_cat_array[''] = esc_html__( 'Select Category','newsrepublic' );

        }

        foreach ( $post_cat_lists as $post_cat_list ) {

            $post_cat_cat_array[$post_cat_list->slug] = $post_cat_list->name;

        }

        return $post_cat_cat_array;
    }

endif;

if( !function_exists('newsrepublic_sanitize_meta_pagination') ):

    /** Sanitize Enable Disable Checkbox **/
    function newsrepublic_sanitize_meta_pagination( $input ) {

        $valid_keys = array('global-layout','no-navigation','norma-navigation','ajax-next-post-load');
        if ( in_array( $input , $valid_keys ) ) {
            return $input;
        }
        return '';

    }

endif;

if( !function_exists('newsrepublic_disable_post_views') ):

    /** Disable Post Views **/
    function newsrepublic_disable_post_views() {

        add_filter('booster_extension_filter_views_ed', 'newsrepublic_disable_views_ed');

    }

endif;

if( !function_exists('newsrepublic_disable_views_ed') ):

    /** Disable Reaction **/
    function newsrepublic_disable_views_ed() {

        return false;

    }

endif;

if( !function_exists('newsrepublic_disable_post_read_time') ):

    /** Disable Read Time **/
    function newsrepublic_disable_post_read_time() {

        add_filter('booster_extension_filter_readtime_ed', 'newsrepublic_disable_read_time');

    }

endif;

if( !function_exists('newsrepublic_disable_read_time') ):

    /** Disable Reaction **/
    function newsrepublic_disable_read_time() {

        return false;

    }

endif;

if( !function_exists('newsrepublic_disable_post_like_dislike') ):

    /** Disable Like Dislike **/
    function newsrepublic_disable_post_like_dislike() {

        add_filter('booster_extension_filter_like_ed', 'newsrepublic_disable_like_ed');

    }

endif;

if( !function_exists('newsrepublic_disable_like_ed') ):

    /** Disable Reaction **/
    function newsrepublic_disable_like_ed() {

        return false;

    }

endif;

if( !function_exists('newsrepublic_disable_post_author_box') ):

    /** Disable Author Box **/
    function newsrepublic_disable_post_author_box() {

        add_filter('booster_extension_filter_ab_ed','newsrepublic_disable_ab_ed');

    }

endif;

if( !function_exists('newsrepublic_disable_ab_ed') ):

    /** Disable Reaction **/
    function newsrepublic_disable_ab_ed() {

        return false;

    }

endif;

add_filter('booster_extension_filter_ss_ed', 'newsrepublic_disable_social_share');

if( !function_exists('newsrepublic_disable_social_share') ):

    /** Disable Reaction **/
    function newsrepublic_disable_social_share() {

        return false;

    }

endif;

if( !function_exists('newsrepublic_disable_post_reaction') ):

    /** Disable Reaction **/
    function newsrepublic_disable_post_reaction() {

        add_filter('booster_extension_filter_reaction_ed', 'newsrepublic_disable_reaction_cb');

    }

endif;

if( !function_exists('newsrepublic_disable_reaction_cb') ):

    /** Disable Reaction **/
    function newsrepublic_disable_reaction_cb() {

        return false;

    }

endif;

if( !function_exists( 'newsrepublic_header_ad' ) ):

    function newsrepublic_header_ad(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $ed_header_ad = get_theme_mod( 'ed_header_ad',$newsrepublic_default['ed_header_ad'] );
        $header_ad_image = get_theme_mod( 'header_ad_image' );
        $ed_header_link = get_theme_mod( 'ed_header_link' );

        if( $ed_header_ad ){

            ?>

            <div class="theme-header-ads">
                <div class="wrapper">
                    <?php if ($header_ad_image) { ?>
                        <a target="_blank" href="<?php echo esc_url($ed_header_link); ?>">
                            <img src="<?php echo esc_url($header_ad_image); ?>" title="<?php esc_attr_e('Header AD Image', 'newsrepublic'); ?>" alt="<?php esc_attr_e('Header AD Image', 'newsrepublic'); ?>"/>
                        </a>
                    <?php } ?>
                </div>
            </div>

            <?php

        }
    }

endif;

if( !function_exists('newsrepublic_post_floating_nav') ):

    function newsrepublic_post_floating_nav(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $ed_floating_next_previous_nav = get_theme_mod( 'ed_floating_next_previous_nav',$newsrepublic_default['ed_floating_next_previous_nav'] );

        if( 'post' === get_post_type() && $ed_floating_next_previous_nav ){

            $next_post = get_next_post();
            $prev_post = get_previous_post();

            if( isset( $prev_post->ID ) ){

                $prev_link = get_permalink( $prev_post->ID );?>

                <div class="floating-post-navigation floating-navigation-prev">
                    <?php if( get_the_post_thumbnail( $prev_post->ID,'medium' ) ){ ?>
                            <?php echo wp_kses_post( get_the_post_thumbnail( $prev_post->ID,'medium' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $prev_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Previous post', 'newsrepublic'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $prev_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php }

            if( isset( $next_post->ID ) ){

                $next_link = get_permalink( $next_post->ID );?>

                <div class="floating-post-navigation floating-navigation-next">
                    <?php if( get_the_post_thumbnail( $next_post->ID,'medium' ) ){ ?>
                        <?php echo wp_kses_post( get_the_post_thumbnail( $next_post->ID,'medium' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $next_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Next post', 'newsrepublic'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $next_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php
            }

        }

    }

endif;

add_action( 'newsrepublic_navigation_action','newsrepublic_post_floating_nav',10 );

if( !function_exists('newsrepublic_single_post_navigation') ):

    function newsrepublic_single_post_navigation(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $twp_navigation_type = esc_attr( get_post_meta( get_the_ID(), 'twp_disable_ajax_load_next_post', true ) );
        $newsrepublic_header_trending_page = get_theme_mod( 'newsrepublic_header_trending_page' );
        $newsrepublic_header_popular_page = get_theme_mod( 'newsrepublic_header_popular_page' );
        $newsrepublic_archive_layout = esc_attr( get_theme_mod( 'newsrepublic_archive_layout', $newsrepublic_default['newsrepublic_archive_layout'] ) );
        $current_id = '';
        $article_wrap_class = '';
        global $post;
        $current_id = $post->ID;
        if( $twp_navigation_type == '' || $twp_navigation_type == 'global-layout' ){
            $twp_navigation_type = get_theme_mod('twp_navigation_type', $newsrepublic_default['twp_navigation_type']);
        }

        if( $newsrepublic_header_trending_page != $current_id && $newsrepublic_header_popular_page != $current_id ){

            if( $twp_navigation_type != 'no-navigation' && 'post' === get_post_type() ){

                if( $twp_navigation_type == 'norma-navigation' ){ ?>

                    <div class="navigation-wrapper">
                        <?php
                        // Previous/next post navigation.
                        the_post_navigation(array(
                            'prev_text' => '<span class="arrow" aria-hidden="true">' . newsrepublic_theme_svg('arrow-left',$return = true ) . '</span><span class="screen-reader-text">' . __('Previous post:', 'newsrepublic') . '</span><span class="post-title">%title</span>',
                            'next_text' => '<span class="arrow" aria-hidden="true">' . newsrepublic_theme_svg('arrow-right',$return = true ) . '</span><span class="screen-reader-text">' . __('Next post:', 'newsrepublic') . '</span><span class="post-title">%title</span>',
                        )); ?>
                    </div>
                    <?php

                }else{

                    $next_post = get_next_post();
                    if( isset( $next_post->ID ) ){

                        $next_post_id = $next_post->ID;
                        echo '<div loop-count="1" next-post="' . absint( $next_post_id ) . '" class="twp-single-infinity"></div>';

                    }
                }

            }

        }

    }

endif;

add_action( 'newsrepublic_navigation_action','newsrepublic_single_post_navigation',30 );


if( !function_exists('newsrepublic_header_banner') ):

    function newsrepublic_header_banner(){

        global $post;

        if( have_posts() ):

            while (have_posts()) :
                the_post();

                global $post;
                
            endwhile;

        endif;
        
        $newsrepublic_post_layout = '';
        $newsrepublic_default = newsrepublic_get_default_theme_options();

        if( is_singular() ){

            $newsrepublic_post_layout = esc_html( get_post_meta( $post->ID, 'newsrepublic_post_layout', true ) );
            if( $newsrepublic_post_layout == '' || $newsrepublic_post_layout == 'global-layout' ){
                
                $newsrepublic_post_layout = get_theme_mod( 'newsrepublic_single_post_layout',$newsrepublic_default['newsrepublic_archive_layout'] );
            }

        }

        if( isset( $post->ID ) ){

            $newsrepublic_page_layout = esc_html( get_post_meta( $post->ID, 'newsrepublic_page_layout', true ) );

        }

        if( $newsrepublic_post_layout == 'layout-2' && is_singular('post') ) {

            if ( have_posts() ) :

                while ( have_posts() ) :
                    the_post();

                    $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'full' );
                    $newsrepublic_ed_feature_image = esc_html( get_post_meta( get_the_ID(), 'newsrepublic_ed_feature_image', true ) );
                    ?>

                    <div class="single-featured-banner  <?php if( empty( $newsrepublic_ed_feature_image ) && isset( $featured_image[0] ) && $featured_image[0] ){ echo 'banner-has-image'; } ?>">

                        <div class="featured-banner-content">
                            <div class="wrapper">
                                <?php
                                if ( !is_404() && !is_home() && !is_front_page() ) {
                                    newsrepublic_breadcrumb();
                                } ?>

                                <div class="column-row">
                                    <div class="column column-12">
                                        <header class="entry-header">

                                            <div class="entry-meta">
                                                <?php
                                                newsrepublic_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false);
                                                ?>
                                            </div>

                                            <h1 class="entry-title entry-title-large">
                                                <?php the_title(); ?>
                                            </h1>
                                        </header>
                                        <div class="entry-meta">
                                            <?php
                                            newsrepublic_posted_by();
                                            ?>
                                        </div>
                                    </div>
                                </div>
                                
                            </div>
                        </div>

                        <?php if( empty( $newsrepublic_ed_feature_image ) && isset( $featured_image[0] ) && $featured_image[0] ){ ?>
                            <div class="featured-banner-media">
                                <div class="data-bg data-bg-fixed data-bg-banner" data-background="<?php echo esc_url( $featured_image[0] ); ?>"></div>
                            </div>
                        <?php } ?>

                    </div>

                <?php
                endwhile;

                wp_reset_postdata();

            endif;
               
        }

        if( is_singular('page') && $newsrepublic_page_layout == 'layout-2' ) {

            if ( have_posts() ) :

                while ( have_posts() ) :

                    the_post();

                    $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'full' );
                    
                    $newsrepublic_ed_feature_image = esc_html( get_post_meta( get_the_ID(), 'newsrepublic_ed_feature_image', true ) );
                    ?>

                    <div class="single-featured-banner  <?php if( empty( $newsrepublic_ed_feature_image ) && isset( $featured_image[0] ) && $featured_image[0] ){ echo 'banner-has-image'; } ?>">

                        <div class="featured-banner-content">
                            <div class="wrapper">
                                <?php
                                if ( !is_404() && !is_home() && !is_front_page() ) {
                                    newsrepublic_breadcrumb();
                                } ?>

                                <div class="column-row">
                                    <div class="column column-12">
                                        <header class="entry-header">

                                            <h1 class="entry-title entry-title-large">
                                                <?php the_title(); ?>
                                            </h1>
                                        </header>
                                    </div>
                                </div>
                                
                            </div>
                        </div>

                        <?php if( empty( $newsrepublic_ed_feature_image ) && isset( $featured_image[0] ) && $featured_image[0] ){ ?>
                            <div class="featured-banner-media">
                                <div class="data-bg data-bg-fixed data-bg-banner" data-background="<?php echo esc_url( $featured_image[0] ); ?>"></div>
                            </div>
                        <?php } ?>

                    </div>

                <?php
                endwhile;

                wp_reset_postdata();

            endif;
               
        }

    }

endif;

if ( ! function_exists( 'newsrepublic_header_toggle_search' ) ):

    /**
     * Header Search
     **/
    function newsrepublic_header_toggle_search() { ?>

        <div class="header-searchbar">
            <div class="header-searchbar-inner">
                <div class="wrapper">
                    <div class="header-searchbar-panel">

                        <div class="header-searchbar-area">
                            <a class="skip-link-search-top" href="javascript:void(0)"></a>
                            <?php get_search_form(); ?>
                        </div>

                        <button type="button" id="search-closer" class="close-popup">
                            <?php newsrepublic_theme_svg('cross'); ?>
                        </button>
                    </div>
                </div>
            </div>
        </div>

    <?php
    }

endif;

add_action( 'newsrepublic_before_footer_content_action','newsrepublic_header_toggle_search',10 );


if( !function_exists('newsrepublic_theme_topbar') ):

    function newsrepublic_theme_topbar(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $ed_ticker_bar = get_theme_mod( 'ed_ticker_bar', $newsrepublic_default['ed_ticker_bar'] );

        if( $ed_ticker_bar ){ ?>

            <div id="theme-topbar" class="theme-header-topbar">
                
                <?php newsrepublic_extra_area_render(); ?>

            </div>

        <?php
        }

    }

endif;

if( !function_exists('newsrepublic_extra_area_render') ):

    function newsrepublic_extra_area_render( $render = true ){

        ob_start();

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $ed_ticker_bar = get_theme_mod( 'ed_ticker_bar', $newsrepublic_default['ed_ticker_bar'] );
        $ed_ticker_bar_date = get_theme_mod( 'ed_ticker_bar_date', $newsrepublic_default['ed_ticker_bar_date'] );
        $ticker_date_format = get_theme_mod( 'ticker_date_format', $newsrepublic_default['ticker_date_format'] );
        $ed_ticker_bar_social_nav = get_theme_mod( 'ed_ticker_bar_social_nav', $newsrepublic_default['ed_ticker_bar_social_nav'] );

        if( $ed_ticker_bar && ( has_nav_menu('newsrepublic-social-menu') || $ed_ticker_bar_date ) ){ ?>

            <div class="wrapper header-wrapper">
                <div class="header-item header-item-left">
                    <?php
                    if ($ed_ticker_bar_date) {
                     ?>
                        <div class="theme-header-topbar-item theme-header-topbar-date">
                            <span class="theme-header-topbar-icon"><?php newsrepublic_theme_svg('calendar-full'); ?></span>
                            <span class="theme-header-topbar-label"><?php echo esc_html(get_the_date( esc_attr($ticker_date_format))); ?></span>
                        </div>
                    <?php } ?>

                    <div class="theme-header-topbar-item theme-header-topbar-clock">
                        <span class="theme-header-topbar-icon"><?php newsrepublic_theme_svg('clock'); ?></span>
                        <span class="theme-header-topbar-label">
                            <div id="twp-time-clock"></div>
                        </span>
                    </div>

                </div>


                <div class="header-item header-item-right">
                    <?php newsrepublic_category_pin_posts_link(); ?>

                    <?php
                    if (has_nav_menu('newsrepublic-social-menu') && $ed_ticker_bar_social_nav) { ?>
                        <div class="topbar-social-navigation">
                            <?php
                            wp_nav_menu(

                                array(
                                    'theme_location' => 'newsrepublic-social-menu',
                                    'link_before' => '<span class="screen-reader-text">',
                                    'link_after' => '</span>',
                                    'container' => 'div',
                                    'container_class' => 'newsrepublic-social-menu',
                                    'depth' => 1,
                                )

                            ); ?>
                        </div>
                    <?php } ?>

                </div>
            </div>

        <?php
        }

        $html = ob_get_contents();
        ob_get_clean();

        if( $render ){

            echo $html;

        }else{

            return $html;

        }

    }

endif;

if( !function_exists('newsrepublic_content_offcanvas') ):

    // Offcanvas Contents
    function newsrepublic_content_offcanvas(){

    $responsive_content = false;
    $newsrepublic_default = newsrepublic_get_default_theme_options();
    $ed_ticker_bar = get_theme_mod( 'ed_ticker_bar', $newsrepublic_default['ed_ticker_bar'] );
    $ed_ticker_bar_date = get_theme_mod( 'ed_ticker_bar_date', $newsrepublic_default['ed_ticker_bar_date'] );

    if( $ed_ticker_bar && ( has_nav_menu('newsrepublic-social-menu') || $ed_ticker_bar_date ) ){

        $responsive_content = true;

    }
     ?>

        <div id="offcanvas-menu">
            <div class="offcanvas-wraper">

                <div class="close-offcanvas-menu">

                    <a class="skip-link-off-canvas" href="javascript:void(0)"></a>

                    <div class="offcanvas-close">

                        <?php if( $responsive_content ){ ?>
                             <div class="offcanvas-close-items">
                                <div class="responsive-content-date"></div>
                                <div class="responsive-content-clock">
                                    <span class="theme-extrabar-icon">
                                        <?php newsrepublic_theme_svg('clock'); ?>
                                    </span>
                                    <span class="theme-extrabar-label">
                                        <div id="twp-time-clock"></div>
                                    </span>
                                </div>
                            </div>
                        <?php } ?>

                        <button type="button" class="button-offcanvas-close">

                            <span class="offcanvas-close-label">
                                <?php echo esc_html__('Close', 'newsrepublic'); ?>
                            </span>

                            <span class="bars">
                                <span class="bar"></span>
                                <span class="bar"></span>
                                <span class="bar"></span>
                            </span>

                        </button>

                    </div>
                </div>

                <div id="primary-nav-offcanvas" class="offcanvas-item offcanvas-main-navigation">
                    <nav class="primary-menu-wrapper">
                        <ul class="primary-menu theme-menu">

                            <?php
                            if( has_nav_menu('newsrepublic-primary-menu') ){

                                wp_nav_menu(
                                    array(
                                        'container' => '',
                                        'items_wrap' => '%3$s',
                                        'theme_location' => 'newsrepublic-primary-menu',
                                        'show_toggles' => true,
                                    )
                                );

                            }else{

                                wp_list_pages(
                                    array(
                                        'match_menu_classes' => true,
                                        'title_li' => false,
                                        'show_toggles' => true,
                                        'walker' => new Newsrepublic_Walker_Page(),
                                    )
                                );

                            } ?>

                        </ul>
                    </nav>
                </div>

                <?php if (has_nav_menu('newsrepublic-social-menu')) { ?>

                    <div id="social-nav-offcanvas" class="offcanvas-item offcanvas-social-navigation">

                        <?php
                        wp_nav_menu(
                                array(
                                'theme_location' => 'newsrepublic-social-menu',
                                'link_before' => '<span class="screen-reader-text">',
                                'link_after' => '</span>',
                                'container' => 'div',
                                'container_class' => 'newsrepublic-social-menu',
                                'depth' => 1,
                            )
                        ); ?>

                    </div>

                <?php }

                if( $responsive_content ){ ?>
                    <div class="responsive-content-menu">

                    </div>
                <?php } ?>

                <a class="skip-link-offcanvas screen-reader-text" href="javascript:void(0)"></a>
                
            </div>
        </div>

    <?php
    }

endif;

add_action( 'newsrepublic_before_footer_content_action','newsrepublic_content_offcanvas',30 );

if( !function_exists('newsrepublic_footer_content_widget') ):

    function newsrepublic_footer_content_widget(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        if (is_active_sidebar('newsrepublic-footer-widget-0') || 
            is_active_sidebar('newsrepublic-footer-widget-1') || 
            is_active_sidebar('newsrepublic-footer-widget-2')):
            $x = 1;
            $footer_sidebar = 0;
            do {
                if ($x == 4 && is_active_sidebar('newsrepublic-footer-widget-3')) {
                    $footer_sidebar++;
                }
                if ($x == 3 && is_active_sidebar('newsrepublic-footer-widget-2')) {
                    $footer_sidebar++;
                }
                if ($x == 2 && is_active_sidebar('newsrepublic-footer-widget-1')) {
                    $footer_sidebar++;
                }
                if ($x == 1 && is_active_sidebar('newsrepublic-footer-widget-0')) {
                    $footer_sidebar++;
                }
                $x++;
            } while ($x <= 4);
            if ($footer_sidebar == 1) {
                $footer_sidebar_class = 12;
            } elseif ($footer_sidebar == 2) {
                $footer_sidebar_class = 6;
            } elseif ($footer_sidebar == 3) {
                $footer_sidebar_class = 4;
            }else {
                $footer_sidebar_class = 3;
            }
            $footer_column_layout = absint(get_theme_mod('footer_column_layout', $newsrepublic_default['footer_column_layout'])); ?>

            <div class="footer-widgetarea">
                <div class="wrapper">
                    <div class="column-row">
                        <?php if (is_active_sidebar('newsrepublic-footer-widget-0')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-6 column-xs-12">
                                <?php dynamic_sidebar('newsrepublic-footer-widget-0'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('newsrepublic-footer-widget-1')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-6 column-xs-12">
                                <?php dynamic_sidebar('newsrepublic-footer-widget-1'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('newsrepublic-footer-widget-2')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-6 column-xs-12">
                                <?php dynamic_sidebar('newsrepublic-footer-widget-2'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('newsrepublic-footer-widget-3')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-6 column-xs-12">
                                <?php dynamic_sidebar('newsrepublic-footer-widget-3'); ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php
        endif;

    }

endif;

add_action( 'newsrepublic_footer_content_action','newsrepublic_footer_content_widget',10 );

if( !function_exists('newsrepublic_footer_content_info') ):

    /**
     * Footer Copyright Area
    **/
    function newsrepublic_footer_content_info(){

        $newsrepublic_default = newsrepublic_get_default_theme_options(); ?>
        <div class="site-info">
            <div class="wrapper">
                <div class="column-row">
                    <div class="column column-8 column-sm-12">
                        <div class="footer-copyright">
                            <?php
                            $footer_copyright_text = wp_kses_post( get_theme_mod( 'footer_copyright_text', $newsrepublic_default['footer_copyright_text'] ) );
                            echo esc_html__('Copyright ', 'newsrepublic') . '&copy ' . absint(date('Y')) . ' <a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name', 'display')) . '" ><span>' . esc_html( get_bloginfo( 'name', 'display' ) ) . '. </span></a> ' . esc_html( $footer_copyright_text );

                            echo '<br>';
                            echo esc_html__('Theme: ', 'newsrepublic') . 'NewsRepublic ' . esc_html__('By ', 'newsrepublic') . '<a href="' . esc_url('https://www.themeinwp.com/theme/newsrepublic') . '"  title="' . esc_attr__('Themeinwp', 'newsrepublic') . '" target="_blank" rel="author"><span>' . esc_html__('Themeinwp. ', 'newsrepublic') . '</span></a>';
                            echo esc_html__('Powered by ', 'newsrepublic') . '<a href="' . esc_url('https://wordpress.org') . '" title="' . esc_attr__('WordPress', 'newsrepublic') . '" target="_blank"><span>' . esc_html__('WordPress.', 'newsrepublic') . '</span></a>';
                            
                            ?>
                        </div>
                    </div>


                    <?php
                    if (has_nav_menu('newsrepublic-social-menu')) { ?>
                        <div class="column column-4 column-sm-12">
                            <div class="footer-social-navigation">
                                <?php
                                wp_nav_menu(

                                    array(
                                        'theme_location' => 'newsrepublic-social-menu',
                                        'link_before' => '<span class="screen-reader-text">',
                                        'link_after' => '</span>',
                                        'container' => 'div',
                                        'container_class' => 'newsrepublic-social-menu',
                                        'depth' => 1,
                                    )

                                ); ?>

                            </div>
                        </div>
                    <?php } ?>

                </div>
            </div>
            <?php newsrepublic_footer_go_to_top(); ?>
        </div>

    <?php
    }

endif;

add_action( 'newsrepublic_footer_content_action','newsrepublic_footer_content_info',20 );


if( !function_exists('newsrepublic_footer_go_to_top') ):

    // Scroll to Top render content
    function newsrepublic_footer_go_to_top(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $ed_scroll_top_button = get_theme_mod( 'ed_scroll_top_button', $newsrepublic_default['ed_scroll_top_button'] );

        if( $ed_scroll_top_button ){
            
            ?>

            <div class="hide-no-js">
                <button type="button" class="scroll-up">
                    <?php newsrepublic_theme_svg('chevron-up'); ?>
                </button>
            </div>

            <?php

        }

    }

endif;


if( !function_exists( 'newsrepublic_post_view_count' ) ):

    function newsrepublic_post_view_count(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $ed_post_views = get_theme_mod( 'ed_post_views', $newsrepublic_default['ed_post_views'] );
        $twp_be_settings = get_option('twp_be_options_settings');
        $twp_be_enable_post_visit_tracking = isset( $twp_be_settings[ 'twp_be_enable_post_visit_tracking' ] ) ? esc_html( $twp_be_settings[ 'twp_be_enable_post_visit_tracking' ] ) : '';
        if( $twp_be_enable_post_visit_tracking && class_exists( 'Booster_Extension_Class' ) ): ?>

            <div class="entry-meta-item entry-meta-views">
                <span class="entry-meta-icon views-icon">
                    <?php newsrepublic_theme_svg('viewer'); ?>
                </span>
                <a href="<?php the_permalink(); ?>">
                    <span class="post-view-count">
                       <?php
                       echo do_shortcode('[booster-extension-visit-count count_only="count" label="'.esc_html__('Views','newsrepublic').'"]');
                       ?>
                    </span>
                 </a>
            </div>
        
        <?php
        endif;
    }
endif;

if( !function_exists( 'newsrepublic_post_like_dislike' ) ):

    function newsrepublic_post_like_dislike(){

        $newsrepublic_ed_post_like_dislike = esc_html( get_post_meta( get_the_ID(), 'newsrepublic_ed_post_like_dislike', true ) );
        if( class_exists( 'Booster_Extension_Class' ) && !$newsrepublic_ed_post_like_dislike ): ?>

            <div class="entry-meta-item entry-meta-like-dislike">
                <?php echo do_shortcode('[booster-extension-like-dislike]'); ?>
            </div>
        
        <?php
        endif;
    }
endif;


add_action('wp_ajax_newsrepublic_tab_posts_callback', 'newsrepublic_tab_posts_callback');
add_action('wp_ajax_nopriv_newsrepublic_tab_posts_callback', 'newsrepublic_tab_posts_callback');

if( !function_exists( 'newsrepublic_tab_posts_callback' ) ):
    // Masonry Post Ajax Call Function.

    function newsrepublic_tab_posts_callback() {

        if(  isset( $_POST[ '_wpnonce' ] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST[ '_wpnonce' ] ) ), 'newsrepublic_ajax_nonce' ) && isset( $_POST['category'] ) ){

            $category = sanitize_text_field( wp_unslash( $_POST['category'] ) );

            $tab_post_query = new WP_Query( 
                array( 
                    'post_type' => 'post',
                    'posts_per_page' => 7,
                    'post__not_in' => get_option("sticky_posts"),
                    'category_name' => esc_html( $category ),
                    'post_status' => 'publish'
                ) 
            );

            $tab_post_query_1 = new WP_Query( 
                array( 
                    'post_type' => 'post',
                    'posts_per_page' => 7,
                    'post__not_in' => get_option("sticky_posts"),
                    'category_name' => esc_html( $category ),
                    'post_status' => 'publish'
                ) 
            );

            if( $tab_post_query ->have_posts() ): ?>

                <div class="column-row">

                    <div class="column column-6 column-xs-12">

                        <?php
                        $post_count = 1;
                        while ($tab_post_query->have_posts()) {
                            $tab_post_query->the_post();

                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                            $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>
                            <article id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article news-article-panel'); ?>>
                                <div class="data-bg data-bg-medium img-hover-slide" data-background="<?php echo esc_url($featured_image); ?>">

                                    <?php
                                    $format = get_post_format(get_the_ID()) ?: 'standard';
                                    $icon = newsrepublic_post_format_icon($format);
                                    if (!empty($icon)) { ?>
                                        <span class="top-right-icon">
                                            <?php echo newsrepublic_svg_escape($icon); ?>
                                        </span>
                                    <?php } ?>
                                    <a class="img-link" href="<?php the_permalink(); ?>" tabindex="0"></a>
                                    <div class="article-content article-content-overlay">
                                        <div class="entry-meta">
                                            <?php newsrepublic_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                                        </div>
                                        <h3 class="entry-title entry-title-medium">
                                            <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark"
                                               title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
                                        </h3>
                                        <div class="entry-meta">
                                            <?php newsrepublic_posted_by(); ?>
                                            <?php newsrepublic_post_view_count(); ?>
                                        </div>
                                    </div>
                                </div>
                            </article>

                            <?php
                            if( $post_count == 2 ){
                                break;
                            }

                            $post_count++;

                        }
                        wp_reset_postdata(); ?>

                    </div>

                    <div class="column column-6 column-xs-12">
                        <?php
                        $post_count = 1;
                        while ($tab_post_query_1->have_posts()) {
                            $tab_post_query_1->the_post();

                            if( $post_count != 1 && $post_count != 2 ){

                                $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(), 'thumbnail' );
                                $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>


                                    <article id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article news-article-list'); ?>>

                                        <?php if ($featured_image) { ?>
                                            <div class="data-bg img-hover-slide" data-background="<?php echo esc_url($featured_image); ?>">

                                                <?php
                                                $format = get_post_format(get_the_ID()) ?: 'standard';
                                                $icon = newsrepublic_post_format_icon($format);
                                                if (!empty($icon)) { ?>
                                                    <span class="top-right-icon">
                                                                    <?php echo newsrepublic_svg_escape($icon); ?>
                                                                </span>
                                                <?php } ?>
                                                <a class="img-link" href="<?php the_permalink(); ?>" tabindex="0"></a>

                                            </div>
                                        <?php } ?>

                                        <div class="article-content">
                                            <h3 class="entry-title entry-title-small">
                                                <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
                                            </h3>
                                            <div class="entry-meta-wrapper">
                                                <div class="entry-meta entry-meta-default">
                                                    <?php newsrepublic_posted_on( $icon = true ); ?>
                                                </div>
                                                <div class="entry-meta">
                                                    <?php newsrepublic_post_view_count(); ?>
                                                </div>
                                            </div>
                                        </div>
                                    </article>


                                <?php
                            }

                            $post_count++;

                        } ?>
                    </div>


                </div>


                <?php
                wp_reset_postdata();

            endif;
        }

        wp_die();
    }

endif;

if( !function_exists( 'newsrepublic_header_ticker_posts' ) ):

    function newsrepublic_header_ticker_posts(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $ed_header_ticker_posts = get_theme_mod( 'ed_header_ticker_posts',$newsrepublic_default['ed_header_ticker_posts'] );
        $ed_header_ticker_posts_title = get_theme_mod( 'ed_header_ticker_posts_title',$newsrepublic_default['ed_header_ticker_posts_title'] );
        $newsrepublic_header_ticker_cat = get_theme_mod( 'newsrepublic_header_ticker_cat' );
        $slider_autoplay = get_theme_mod( 'ed_ticker_slider_autoplay',$newsrepublic_default['ed_ticker_slider_autoplay'] );
        
        if( $slider_autoplay ){
            $autoplay = 'true';
        }else{
            $autoplay = 'false';
        }
        
        if( is_rtl() ) {
            $rtl = 'right';
        }else{
            $rtl = 'left';
        }

        if( $ed_header_ticker_posts ){ ?>

            <div class="theme-ticker-area hide-no-js">
                <?php if( $ed_header_ticker_posts_title ){ ?>
                    <div class="theme-ticker-components theme-ticker-left">
                        <div class="theme-ticker-title"><?php echo esc_html( $ed_header_ticker_posts_title ); ?></div>
                    </div>
                <?php } ?>

                <?php
                $ticker_posts_query = new WP_Query(array('post_type' => 'post', 'posts_per_page' => 5, 'post__not_in' => get_option("sticky_posts"), 'category_name' => esc_html($newsrepublic_header_ticker_cat)));

                if( $ticker_posts_query->have_posts() ): ?>

                    <div class="theme-ticker-component theme-ticker-right">
                        <div class="ticker-slides" data-direction="left" data-direction='<?php echo esc_attr($rtl); ?>'>
                            <?php
                            while ($ticker_posts_query->have_posts()):
                                $ticker_posts_query->the_post(); ?>


                                        <a class="ticker-slides-item" href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>">
                                            <?php if (has_post_thumbnail()) {
                                                $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'thumbnail');
                                                $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : '';?>
                                                <span class="data-bg ticker-data-bg" data-background="<?php echo esc_url( $featured_image ); ?>"></span>
                                            <?php } ?>
                                            <span class="ticker-title"><?php the_title(); ?></span>
                                        </a>


                                <?php
                            endwhile; ?>
                        </div>
                    </div>

                    <?php
                    wp_reset_postdata();
                endif; ?>
            </div>

        <?php
        }

    }

endif;


if( class_exists('WooCommerce') ){

    remove_action('woocommerce_sidebar','woocommerce_get_sidebar');
    add_action('woocommerce_before_main_content','newsrepublic_woo_before_main_content',5);
    add_action('woocommerce_after_main_content','newsrepublic_woo_after_main_content',15);

}
if( !function_exists('newsrepublic_woo_before_main_content') ):

    function newsrepublic_woo_before_main_content(){

        echo '<div class="wrapper">';
        echo '<div class="column-row">';

    }

endif;

if( !function_exists('newsrepublic_woo_after_main_content') ):

    function newsrepublic_woo_after_main_content(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $sidebar = esc_attr( get_theme_mod( 'global_sidebar_layout', $newsrepublic_default['global_sidebar_layout'] ) );
        if( $sidebar != 'no-sidebar' ){

            get_sidebar();
            
        }

        echo '</div>';
        echo '</div>';

    }

endif;


if( !function_exists('newsrepublic_content_loading') ){

    function newsrepublic_content_loading(){ ?>

        <div class="content-loading-status">
            <div class="theme-ajax-loader"></div>
            <div class="screen-reader-text">
                <?php esc_html_e('Content Loading','newsrepublic'); ?>
            </div>
        </div>
    
    <?php
    }
}


function newsrepublic_hex2rgb( $colour,$opacity = 1 ) {

    if ( $colour[0] == '#' ) {
            $colour = substr( $colour, 1 );
    }
    if ( strlen( $colour ) == 6 ) {
            list( $r, $g, $b ) = array( $colour[0] . $colour[1], $colour[2] . $colour[3], $colour[4] . $colour[5] );
    } elseif ( strlen( $colour ) == 3 ) {
            list( $r, $g, $b ) = array( $colour[0] . $colour[0], $colour[1] . $colour[1], $colour[2] . $colour[2] );
    } else {
            return false;
    }
    $r = hexdec( $r );
    $g = hexdec( $g );
    $b = hexdec( $b );
    return 'rgba('.$r.','.$g.','.$b.','.$opacity.')';

}

if( class_exists( 'Booster_Extension_Class' ) ){

    add_filter('booster_extemsion_content_after_filter','newsrepublic_after_content_pagination');

}

if( !function_exists('newsrepublic_after_content_pagination') ):

    function newsrepublic_after_content_pagination($after_content){

        $pagination_single = wp_link_pages( array(
                    'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'newsrepublic' ),
                    'after'  => '</div>',
                    'echo' => false
                ) );

        $after_content =  $pagination_single.$after_content;

        return $after_content;

    }

endif;

if( ! function_exists( 'newsrepublic_iframe_escape' ) ):
    
    /** Escape Iframe **/
    function newsrepublic_iframe_escape( $input ){

        $all_tags = array(
            'iframe'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'frameborder'=>array(),
                'allow'=>array(),
                'allowfullscreen'=>array(),
            ),
            'video'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'style'=>array(),
                'controls'=>array(),
            )
        );

        return wp_kses($input,$all_tags);
        
    }

endif;

if( ! function_exists( 'newsrepublic_post_permalink' ) ):
    
    function newsrepublic_post_permalink(){
        ?><div class="entry-read-more"><a href="<?php the_permalink(); ?>" class="theme-button theme-button-filled theme-button-small"><?php esc_html_e('Read More','newsrepublic'); ?></a></div><?php
    }

endif;

if( !function_exists('main_navigation_extras') ):

    function main_navigation_extras(){ ?>
        <div class="navbar-controls hide-no-js">
            <?php
            $newsrepublic_default = newsrepublic_get_default_theme_options();
            $ed_header_search = get_theme_mod('ed_header_search',$newsrepublic_default['ed_header_search']);
            if ($ed_header_search) { ?>
                <button type="button" class="navbar-control navbar-control-search">
                    <span class="navbar-control-trigger" tabindex="-1"><?php newsrepublic_theme_svg('search'); ?></span>
                </button>
            <?php }
             ?>

            <button type="button" class="navbar-control navbar-control-offcanvas">
                <span class="navbar-control-trigger" tabindex="-1"><?php newsrepublic_theme_svg('menu'); ?></span>
            </button>

        </div>

    <?php
    }

endif;



if( !function_exists('newsrepublic_video_aspect_ratio') ):

    function newsrepublic_video_aspect_ratio(){

        return $newsrepublic_video_aspect_ratio = array(
            'global' => esc_html__( 'Global', 'newsrepublic' ),
            'default' => esc_html__( 'Default', 'newsrepublic' ),
            'square' => esc_html__( 'Square', 'newsrepublic' ),
            'portrait' => esc_html__( 'Portrait', 'newsrepublic' ),
            'landscape' => esc_html__( 'Landscape', 'newsrepublic' ),
        );

    }

endif;

if( !function_exists('newsrepublic_video_autoplay') ):

    function newsrepublic_video_autoplay(){

        return $newsrepublic_video_autoplay = array(
            'global' => esc_html__( 'Global', 'newsrepublic' ),
            'autoplay-disable' => esc_html__( 'Disable Autoplay', 'newsrepublic' ),
            'autoplay-enable' => esc_html__( 'Enable Autoplay', 'newsrepublic' ),
            
        );

    }

endif;

add_filter('comment_form_defaults','newsrepublic_comment_title_callback');

if( !function_exists('newsrepublic_comment_title_callback') ):


    function newsrepublic_comment_title_callback($defaults){

        $defaults['title_reply_before'] = '<header class="block-title-wrapper"><h3 class="block-title">';
        $defaults['title_reply_after'] = '</h3></header>';
        return $defaults;

    }

endif;


if( class_exists('Booster_Extension_Class') ):

    add_filter('booster_extension_ed_content','newsrepublic_read_letter_content_false');

    if( !function_exists('newsrepublic_read_letter_content_false') ):

        function newsrepublic_read_letter_content_false(){

            return false;

        }

    endif;

    add_action('booster_extension_read_later_post_content','newsrepublic_readletter_content',20);

    if( !function_exists('newsrepublic_readletter_content') ):

        function newsrepublic_readletter_content(){

            return get_template_part( 'template-parts/content', get_post_format() );

        }

    endif;
    
endif;

if( !function_exists('newsrepublic_category_pin_posts_link') ):

    function newsrepublic_category_pin_posts_link(){

        $newsrepublic_default = newsrepublic_get_default_theme_options();
        $ed_post_read_later = get_theme_mod('ed_post_read_later',$newsrepublic_default['ed_post_read_later']);

        if ( $ed_post_read_later && class_exists('Booster_Extension_Class') ):

            if( function_exists('booster_extension_get_read_letter_page_id') ){
            $page_id = booster_extension_get_read_letter_page_id();


            if ($page_id) {

                $page_link = get_page_link($page_id);
                ?>
                <div class="theme-header-topbar-item theme-header-topbar-bookmark">
                    <a href="<?php echo esc_url($page_link); ?>">
                        <span class="theme-header-topbar-icon"><?php newsrepublic_theme_svg('bookmark'); ?></span>
                        <span class="theme-header-topbar-label"><?php esc_html_e('Favourites', 'newsrepublic'); ?></span>
                    </a>
                </div>
            <?php

            }
        }

        endif;

    }

endif;

function newsrepublic_hex_2_rgba($color, $opacity = false) {

    $default = 'rgb(0,0,0)';

    //Return default if no color provided
    if(empty($color))
        return $default;

    //Sanitize $color if "#" is provided
    if ($color[0] == '#' ) {
        $color = substr( $color, 1 );
    }

    //Check if color has 6 or 3 characters and get values
    if (strlen($color) == 6) {
        $hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
    } elseif ( strlen( $color ) == 3 ) {
        $hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
    } else {
        return $default;
    }

    //Convert hexadec to rgb
    $rgb =  array_map('hexdec', $hex);

    //Check if opacity is set(rgba or rgb)
    if($opacity){
        if(abs($opacity) > 1)
            $opacity = 1.0;
        $output = 'rgba('.implode(",",$rgb).','.$opacity.')';
    } else {
        $output = 'rgb('.implode(",",$rgb).')';
    }

    //Return rgb(a) color string
    return $output;
}