<?php
/**
* Custom Functions.
*
* @package NewsRepublic
*/


if( !function_exists( 'newsrepublic_sanitize_sidebar_option' ) ) :

    // Sidebar Option Sanitize.
    function newsrepublic_sanitize_sidebar_option( $newsrepublic_input ){

        $newsrepublic_metabox_options = array( 'global-sidebar','left-sidebar','right-sidebar','no-sidebar' );
        if( in_array( $newsrepublic_input,$newsrepublic_metabox_options ) ){

            return $newsrepublic_input;

        }

        return;

    }

endif;

if( !function_exists( 'newsrepublic_sanitize_single_pagination_layout' ) ) :

    // Sidebar Option Sanitize.
    function newsrepublic_sanitize_single_pagination_layout( $newsrepublic_input ){

        $newsrepublic_single_pagination = array( 'no-navigation','norma-navigation','ajax-next-post-load' );
        if( in_array( $newsrepublic_input,$newsrepublic_single_pagination ) ){

            return $newsrepublic_input;

        }

        return;

    }

endif;

if( !function_exists( 'newsrepublic_sanitize_archive_layout' ) ) :

    // Sidebar Option Sanitize.
    function newsrepublic_sanitize_archive_layout( $newsrepublic_input ){

        $newsrepublic_archive_option = array( 'default','full','grid' );
        if( in_array( $newsrepublic_input,$newsrepublic_archive_option ) ){

            return $newsrepublic_input;

        }

        return;

    }

endif;

if( !function_exists( 'newsrepublic_sanitize_single_post_layout' ) ) :

    // Single Layout Option Sanitize.
    function newsrepublic_sanitize_single_post_layout( $newsrepublic_input ){

        $newsrepublic_single_layout = array( 'layout-1','layout-2' );
        if( in_array( $newsrepublic_input,$newsrepublic_single_layout ) ){

            return $newsrepublic_input;

        }

        return;

    }

endif;

if ( ! function_exists( 'newsrepublic_sanitize_checkbox' ) ) :

	/**
	 * Sanitize checkbox.
	 */
	function newsrepublic_sanitize_checkbox( $newsrepublic_checked ) {

		return ( ( isset( $newsrepublic_checked ) && true === $newsrepublic_checked ) ? true : false );

	}

endif;


if ( ! function_exists( 'newsrepublic_sanitize_select' ) ) :

    /**
     * Sanitize select.
     */
    function newsrepublic_sanitize_select( $newsrepublic_input, $newsrepublic_setting ) {

        // Ensure input is a slug.
        $newsrepublic_input = sanitize_text_field( $newsrepublic_input );

        // Get list of choices from the control associated with the setting.
        $choices = $newsrepublic_setting->manager->get_control( $newsrepublic_setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $newsrepublic_input, $choices ) ? $newsrepublic_input : $newsrepublic_setting->default );

    }

endif;

if ( ! function_exists( 'newsrepublic_sanitize_repeater' ) ) :
    
    /**
    * Sanitise Repeater Field
    */
    function newsrepublic_sanitize_repeater($input){
        $input_decoded = json_decode( $input, true );
        
        if(!empty($input_decoded)) {

            foreach ($input_decoded as $boxes => $box ){

                foreach ($box as $key => $value){

                    if( $key == 'section_ed' 
                        || $key == 'ed_tab' 
                        || $key == 'ed_arrows_carousel' 
                        || $key == 'ed_dots_carousel' 
                        || $key == 'ed_autoplay_carousel' 
                        || $key == 'ed_flip_column' 
                        || $key == 'ed_ribbon_bg'
                    ){

                        $input_decoded[$boxes][$key] = newsrepublic_sanitize_repeater_ed( $value );

                    }elseif( $key == 'home_section_type' ){

                        $input_decoded[$boxes][$key] = newsrepublic_sanitize_home_sections( $value );

                    }elseif( $key == 'ribbon_bg_color_schema' ){

                        $input_decoded[$boxes][$key] = newsrepublic_sanitize_ribbon_bg( $value );

                    }elseif( $key == 'category_color' ){

                        $input_decoded[$boxes][$key] = sanitize_hex_color( $value );

                    }elseif( $key == 'tiles_post_per_page' ){

                        $input_decoded[$boxes][$key] =  absint( $value );

                    }elseif( $key == 'advertise_image' || $key == 'advertise_link' ){

                         $input_decoded[$boxes][$key] = esc_url_raw( $value );

                    }elseif($key == 'section_category' || 
                            $key == 'section_post_slide_cat' || 
                            $key == 'section_post_cat_1' || 
                            $key == 'section_category_1' || 
                            $key == 'section_category_2' || 
                            $key == 'section_category_3' || 
                            $key == 'section_category_4' || 
                            $key == 'category'
                        ){

                        $input_decoded[$boxes][$key] =  newsrepublic_sanitize_category( $value );

                    }else{

                        $input_decoded[$boxes][$key] = sanitize_text_field( $value );

                    }
                    
                }

            }
           
            return json_encode($input_decoded);

        }

        return $input;
    }
endif;

/** Sanitize Enable Disable Checkbox **/
function newsrepublic_sanitize_repeater_ed( $input ) {

    $valid_keys = array('yes','no');
    if ( in_array( $input , $valid_keys ) ) {
        return $input;
    }
    return '';

}

function newsrepublic_sanitize_home_sections( $input ) {

    $home_sections = array(

        'main-banner' => esc_html__('Main Banner Slider','newsrepublic'),
        'banner-blocks-1' => esc_html__('Slider & Tab Block','newsrepublic'),
        'latest-posts-blocks' => esc_html__('Latest Posts Block','newsrepublic'),
        'slider-blocks' => esc_html__('Slider Block','newsrepublic'),
        'tiles-blocks' => esc_html__('Tiles Block','newsrepublic'),
        'advertise-blocks' => esc_html__('Advertise Block','newsrepublic'),
        'home-widget-area' => esc_html__('Widgets Area Block','newsrepublic'),
        'you-may-like-blocks' => esc_html__('You May Like Block','newsrepublic'),

    );
    if ( array_key_exists( $input , $home_sections ) ) {
        return $input;
    }
    return '';

}

/** Sanitize Category **/
function newsrepublic_sanitize_category( $input ) {

   $newsrepublic_post_category_list = newsrepublic_post_category_list();
    if ( array_key_exists( $input , $newsrepublic_post_category_list ) ) {
        return $input;
    }
    return '';

}

function newsrepublic_sanitize_ribbon_bg( $input ) {

    $ribbon_bg = array( 
                    '1' =>  array(
                                    'title' =>  esc_html__( 'Blue', 'newsrepublic' ),
                                    'color' =>  '#3061ff',
                                ),
                    '2' =>  array(
                                    'title' =>  esc_html__( 'Orange', 'newsrepublic' ),
                                    'color' =>  '#fa9000',
                                ),
                    '3' =>  array(
                                    'title' =>  esc_html__( 'Royal Blue', 'newsrepublic' ),
                                    'color' =>  '#00167a',
                                ),
                    '4' =>  array(
                                    'title' =>  esc_html__( 'Pink', 'newsrepublic' ),
                                    'color' =>  '#ff2d55',
                                ),
                );

    if ( array_key_exists( $input , $ribbon_bg ) ) {
        return $input;
    }
    return '';

}

if ( ! function_exists( 'newsrepublic_sanitize_number_range' ) ) :

    /**
     * Sanitize number range.
     *
     * @since 1.0.0
     *
     * @see absint() https://developer.wordpress.org/reference/functions/absint/
     *
     * @param int                  $input Number to check within the numeric range defined by the setting.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return int|string The number, if it is zero or greater and falls within the defined range; otherwise, the setting default.
     */
    function newsrepublic_sanitize_number_range( $input, $setting ) {

        // Ensure input is an absolute integer.
        $input = absint( $input );

        // Get the input attributes associated with the setting.
        $atts = $setting->manager->get_control( $setting->id )->input_attrs;

        // Get min.
        $min = ( isset( $atts['min'] ) ? $atts['min'] : $input );

        // Get max.
        $max = ( isset( $atts['max'] ) ? $atts['max'] : $input );

        // Get Step.
        $step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

        // If the input is within the valid range, return it; otherwise, return the default.
        return ( $min <= $input && $input <= $max && is_int( $input / $step ) ? $input : $setting->default );

    }

endif;
