<?php
/**
* Sidebar Metabox.
*
* @package NewsRepublic
*/
 
add_action( 'add_meta_boxes', 'newsrepublic_metabox' );

if( ! function_exists( 'newsrepublic_metabox' ) ):


    function  newsrepublic_metabox() {
        
        add_meta_box(
            'theme-custom-metabox',
            esc_html__( 'Layout Settings', 'newsrepublic' ),
            'newsrepublic_post_metafield_callback',
            'post', 
            'normal', 
            'high'
        );
        add_meta_box(
            'theme-custom-metabox',
            esc_html__( 'Layout Settings', 'newsrepublic' ),
            'newsrepublic_post_metafield_callback',
            'page',
            'normal', 
            'high'
        ); 
    }

endif;

$newsrepublic_page_layout_options = array(
    'layout-1' => esc_html__( 'Simple Layout', 'newsrepublic' ),
    'layout-2' => esc_html__( 'Banner Layout', 'newsrepublic' ),
);

$newsrepublic_post_sidebar_fields = array(
    'global-sidebar' => array(
                    'id'        => 'post-global-sidebar',
                    'value' => 'global-sidebar',
                    'label' => esc_html__( 'Global sidebar', 'newsrepublic' ),
                ),
    'right-sidebar' => array(
                    'id'        => 'post-left-sidebar',
                    'value' => 'right-sidebar',
                    'label' => esc_html__( 'Right sidebar', 'newsrepublic' ),
                ),
    'left-sidebar' => array(
                    'id'        => 'post-right-sidebar',
                    'value'     => 'left-sidebar',
                    'label'     => esc_html__( 'Left sidebar', 'newsrepublic' ),
                ),
    'no-sidebar' => array(
                    'id'        => 'post-no-sidebar',
                    'value'     => 'no-sidebar',
                    'label'     => esc_html__( 'No sidebar', 'newsrepublic' ),
                ),
);

$newsrepublic_post_layout_options = array(
    'global-layout' => esc_html__( 'Global Layout', 'newsrepublic' ),
    'layout-1' => esc_html__( 'Simple Layout', 'newsrepublic' ),
    'layout-2' => esc_html__( 'Banner Layout', 'newsrepublic' ),
);

$newsrepublic_header_overlay_options = array(
    'global-layout' => esc_html__( 'Global Layout', 'newsrepublic' ),
    'enable-overlay' => esc_html__( 'Enable Header Overlay', 'newsrepublic' ),
);


/**
 * Callback function for post option.
*/
if( ! function_exists( 'newsrepublic_post_metafield_callback' ) ):
    
    function newsrepublic_post_metafield_callback() {
        global $post, $newsrepublic_post_sidebar_fields, $newsrepublic_post_layout_options,  $newsrepublic_page_layout_options, $newsrepublic_header_overlay_options;
        $post_type = get_post_type($post->ID);
        wp_nonce_field( basename( __FILE__ ), 'newsrepublic_post_meta_nonce' ); ?>
        
        <div class="metabox-main-block">

            <div class="metabox-navbar">
                <ul>

                    <li>
                        <a id="metabox-navbar-general" class="metabox-navbar-active" href="javascript:void(0)">

                            <?php esc_html_e('General Settings', 'newsrepublic'); ?>

                        </a>
                    </li>

                    <li>
                        <a id="metabox-navbar-appearance" href="javascript:void(0)">

                            <?php esc_html_e('Appearance Settings', 'newsrepublic'); ?>

                        </a>
                    </li>

                    <?php if( $post_type == 'post' && class_exists('Booster_Extension_Class') ): ?>
                        <li>
                            <a id="twp-tab-booster" href="javascript:void(0)">

                                <?php esc_html_e('Booster Extension Settings', 'newsrepublic'); ?>

                            </a>
                        </li>
                    <?php endif; ?>

                </ul>
            </div>

            <div class="twp-tab-content">

                <div id="metabox-navbar-general-content" class="metabox-content-wrap metabox-content-wrap-active">

                    <div class="metabox-opt-panel">

                        <h3 class="meta-opt-title"><?php esc_html_e('Sidebar Layout','newsrepublic'); ?></h3>

                        <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                            <?php
                            $newsrepublic_post_sidebar = esc_html( get_post_meta( $post->ID, 'newsrepublic_post_sidebar_option', true ) ); 
                            if( $newsrepublic_post_sidebar == '' ){ $newsrepublic_post_sidebar = 'global-sidebar'; }

                            foreach ( $newsrepublic_post_sidebar_fields as $newsrepublic_post_sidebar_field) { ?>

                                <label class="description">

                                    <input type="radio" name="newsrepublic_post_sidebar_option" value="<?php echo esc_attr( $newsrepublic_post_sidebar_field['value'] ); ?>" <?php if( $newsrepublic_post_sidebar_field['value'] == $newsrepublic_post_sidebar ){ echo "checked='checked'";} if( empty( $newsrepublic_post_sidebar ) && $newsrepublic_post_sidebar_field['value']=='right-sidebar' ){ echo "checked='checked'"; } ?>/>&nbsp;<?php echo esc_html( $newsrepublic_post_sidebar_field['label'] ); ?>

                                </label>

                            <?php } ?>

                        </div>

                    </div>

                </div>


                <div id="metabox-navbar-appearance-content" class="metabox-content-wrap">

                    <?php if( $post_type == 'page' ): ?>

                        <div class="metabox-opt-panel">

                            <h3 class="meta-opt-title"><?php esc_html_e('Appearance Layout','newsrepublic'); ?></h3>

                            <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                                <?php
                                $newsrepublic_page_layout = esc_html( get_post_meta( $post->ID, 'newsrepublic_page_layout', true ) ); 
                                if( $newsrepublic_page_layout == '' ){ $newsrepublic_page_layout = 'layout-1'; }

                                foreach ( $newsrepublic_page_layout_options as $key => $newsrepublic_page_layout_option) { ?>

                                    <label class="description">
                                        <input type="radio" name="newsrepublic_page_layout" value="<?php echo esc_attr( $key ); ?>" <?php if( $key == $newsrepublic_page_layout ){ echo "checked='checked'";} ?>/>&nbsp;<?php echo esc_html( $newsrepublic_page_layout_option ); ?>
                                    </label>

                                <?php } ?>

                            </div>

                        </div>

                        <div class="metabox-opt-panel">

                            <h3 class="meta-opt-title"><?php esc_html_e('Header Overlay','newsrepublic'); ?></h3>

                            <div class="metabox-opt-wrap theme-checkbox-wrap">

                                <?php
                                $newsrepublic_ed_header_overlay = esc_attr( get_post_meta( $post->ID, 'newsrepublic_ed_header_overlay', true ) ); ?>

                                <input type="checkbox" id="newsrepublic-header-overlay" name="newsrepublic_ed_header_overlay" value="1" <?php if( $newsrepublic_ed_header_overlay ){ echo "checked='checked'";} ?>/>

                                <label for="newsrepublic-header-overlay"><?php esc_html_e( 'Enable Header Overlay','newsrepublic' ); ?></label>

                            </div>

                        </div>

                    <?php endif; ?>

                    <?php if( $post_type == 'post' ): ?>

                        <div class="metabox-opt-panel">

                            <h3 class="meta-opt-title"><?php esc_html_e('Appearance Layout','newsrepublic'); ?></h3>

                            <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                                <?php
                                $newsrepublic_post_layout = esc_html( get_post_meta( $post->ID, 'newsrepublic_post_layout', true ) ); 
                                if( $newsrepublic_post_layout == '' ){ $newsrepublic_post_layout = 'global-layout'; }

                                foreach ( $newsrepublic_post_layout_options as $key => $newsrepublic_post_layout_option) { ?>

                                    <label class="description">
                                        <input type="radio" name="newsrepublic_post_layout" value="<?php echo esc_attr( $key ); ?>" <?php if( $key == $newsrepublic_post_layout ){ echo "checked='checked'";} ?>/>&nbsp;<?php echo esc_html( $newsrepublic_post_layout_option ); ?>
                                    </label>

                                <?php } ?>

                            </div>

                        </div>

                        <div class="metabox-opt-panel">

                            <h3 class="meta-opt-title"><?php esc_html_e('Header Overlay','newsrepublic'); ?></h3>

                            <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                                <?php
                                $newsrepublic_header_overlay = esc_html( get_post_meta( $post->ID, 'newsrepublic_header_overlay', true ) ); 
                                if( $newsrepublic_header_overlay == '' ){ $newsrepublic_header_overlay = 'global-layout'; }

                                foreach ( $newsrepublic_header_overlay_options as $key => $newsrepublic_header_overlay_option) { ?>

                                    <label class="description">
                                        <input type="radio" name="newsrepublic_header_overlay" value="<?php echo esc_attr( $key ); ?>" <?php if( $key == $newsrepublic_header_overlay ){ echo "checked='checked'";} ?>/>&nbsp;<?php echo esc_html( $newsrepublic_header_overlay_option ); ?>
                                    </label>

                                <?php } ?>

                            </div>

                        </div>

                    <?php endif; ?>

                    <div class="metabox-opt-panel">

                        <h3 class="meta-opt-title"><?php esc_html_e('Feature Image Setting','newsrepublic'); ?></h3>

                        <div class="metabox-opt-wrap theme-checkbox-wrap">

                            <?php
                            $newsrepublic_ed_feature_image = esc_html( get_post_meta( $post->ID, 'newsrepublic_ed_feature_image', true ) ); 
                            if (!isset( $_POST['newsrepublic_ed_feature_image'] )) {
                                $newsrepublic_ed_feature_image = get_theme_mod('ed_post_thumbnail');
                            }
                            ?>

                            <input type="checkbox" id="newsrepublic-ed-feature-image" name="newsrepublic_ed_feature_image" value="<?php echo $newsrepublic_default_feature_image; ?>" <?php if( $newsrepublic_ed_feature_image ){ echo "checked='checked'";} ?>/>

                            <label for="newsrepublic-ed-feature-image"><?php esc_html_e( 'Disable Feature Image','newsrepublic' ); ?></label>


                        </div>

                    </div>

                     <div class="metabox-opt-panel">

                        <h3 class="meta-opt-title"><?php esc_html_e('Navigation Setting','newsrepublic'); ?></h3>

                        <?php $twp_disable_ajax_load_next_post = esc_attr( get_post_meta($post->ID, 'twp_disable_ajax_load_next_post', true) ); ?>
                        <div class="metabox-opt-wrap metabox-opt-wrap-alt">

                            <label><b><?php esc_html_e( 'Navigation Type','newsrepublic' ); ?></b></label>

                            <select name="twp_disable_ajax_load_next_post">

                                <option <?php if( $twp_disable_ajax_load_next_post == '' || $twp_disable_ajax_load_next_post == 'global-layout' ){ echo 'selected'; } ?> value="global-layout"><?php esc_html_e('Global Layout','newsrepublic'); ?></option>
                                <option <?php if( $twp_disable_ajax_load_next_post == 'no-navigation' ){ echo 'selected'; } ?> value="no-navigation"><?php esc_html_e('Disable Navigation','newsrepublic'); ?></option>
                                <option <?php if( $twp_disable_ajax_load_next_post == 'norma-navigation' ){ echo 'selected'; } ?> value="norma-navigation"><?php esc_html_e('Next Previous Navigation','newsrepublic'); ?></option>
                                <option <?php if( $twp_disable_ajax_load_next_post == 'ajax-next-post-load' ){ echo 'selected'; } ?> value="ajax-next-post-load"><?php esc_html_e('Ajax Load Next 3 Posts Contents','newsrepublic'); ?></option>

                            </select>

                        </div>
                    </div>

                </div>

                <?php if( $post_type == 'post' && class_exists('Booster_Extension_Class') ):

                    
                    $newsrepublic_ed_post_views = esc_html( get_post_meta( $post->ID, 'newsrepublic_ed_post_views', true ) );
                    $newsrepublic_ed_post_read_time = esc_html( get_post_meta( $post->ID, 'newsrepublic_ed_post_read_time', true ) );
                    $newsrepublic_ed_post_like_dislike = esc_html( get_post_meta( $post->ID, 'newsrepublic_ed_post_like_dislike', true ) );
                    $newsrepublic_ed_post_author_box = esc_html( get_post_meta( $post->ID, 'newsrepublic_ed_post_author_box', true ) );
                    $newsrepublic_ed_post_social_share = esc_html( get_post_meta( $post->ID, 'newsrepublic_ed_post_social_share', true ) );
                    $newsrepublic_ed_post_reaction = esc_html( get_post_meta( $post->ID, 'newsrepublic_ed_post_reaction', true ) );
                    $newsrepublic_ed_post_rating = esc_html( get_post_meta( $post->ID, 'newsrepublic_ed_post_rating', true ) );
                    ?>

                    <div id="twp-tab-booster-content" class="metabox-content-wrap">

                        <div class="metabox-opt-panel">

                            <h3 class="meta-opt-title"><?php esc_html_e('Booster Extension Plugin Content','newsrepublic'); ?></h3>

                            <div class="metabox-opt-wrap theme-checkbox-wrap">

                                    <input type="checkbox" id="newsrepublic-ed-post-views" name="newsrepublic_ed_post_views" value="1" <?php if( $newsrepublic_ed_post_views ){ echo "checked='checked'";} ?>/>
                                    <label for="newsrepublic-ed-post-views"><?php esc_html_e( 'Disable Post Views','newsrepublic' ); ?></label>

                            </div>

                            <div class="metabox-opt-wrap theme-checkbox-wrap">

                                    <input type="checkbox" id="newsrepublic-ed-post-read-time" name="newsrepublic_ed_post_read_time" value="1" <?php if( $newsrepublic_ed_post_read_time ){ echo "checked='checked'";} ?>/>
                                    <label for="newsrepublic-ed-post-read-time"><?php esc_html_e( 'Disable Post Read Time','newsrepublic' ); ?></label>

                            </div>

                            <div class="metabox-opt-wrap theme-checkbox-wrap">

                                    <input type="checkbox" id="newsrepublic-ed-post-like-dislike" name="newsrepublic_ed_post_like_dislike" value="1" <?php if( $newsrepublic_ed_post_like_dislike ){ echo "checked='checked'";} ?>/>
                                    <label for="newsrepublic-ed-post-like-dislike"><?php esc_html_e( 'Disable Post Like Dislike','newsrepublic' ); ?></label>

                            </div>

                            <div class="metabox-opt-wrap theme-checkbox-wrap">

                                    <input type="checkbox" id="newsrepublic-ed-post-author-box" name="newsrepublic_ed_post_author_box" value="1" <?php if( $newsrepublic_ed_post_author_box ){ echo "checked='checked'";} ?>/>
                                    <label for="newsrepublic-ed-post-author-box"><?php esc_html_e( 'Disable Post Author Box','newsrepublic' ); ?></label>

                            </div>

                            <div class="metabox-opt-wrap theme-checkbox-wrap">

                                    <input type="checkbox" id="newsrepublic-ed-post-social-share" name="newsrepublic_ed_post_social_share" value="1" <?php if( $newsrepublic_ed_post_social_share ){ echo "checked='checked'";} ?>/>
                                    <label for="newsrepublic-ed-post-social-share"><?php esc_html_e( 'Disable Post Social Share','newsrepublic' ); ?></label>

                            </div>

                            <div class="metabox-opt-wrap theme-checkbox-wrap">

                                    <input type="checkbox" id="newsrepublic-ed-post-reaction" name="newsrepublic_ed_post_reaction" value="1" <?php if( $newsrepublic_ed_post_reaction ){ echo "checked='checked'";} ?>/>
                                    <label for="newsrepublic-ed-post-reaction"><?php esc_html_e( 'Disable Post Reaction','newsrepublic' ); ?></label>

                            </div>

                            <div class="metabox-opt-wrap theme-checkbox-wrap">

                                    <input type="checkbox" id="newsrepublic-ed-post-rating" name="newsrepublic_ed_post_rating" value="1" <?php if( $newsrepublic_ed_post_rating ){ echo "checked='checked'";} ?>/>
                                    <label for="newsrepublic-ed-post-rating"><?php esc_html_e( 'Disable Post Rating','newsrepublic' ); ?></label>

                            </div>

                        </div>

                    </div>

                <?php endif; ?>
                
            </div>

        </div>  
            
    <?php }
endif;

// Save metabox value.
add_action( 'save_post', 'newsrepublic_save_post_meta' );

if( ! function_exists( 'newsrepublic_save_post_meta' ) ):

    function newsrepublic_save_post_meta( $post_id ) {

        global $post, $newsrepublic_post_sidebar_fields, $newsrepublic_post_layout_options, $newsrepublic_header_overlay_options,  $newsrepublic_page_layout_options;

        if ( !isset( $_POST[ 'newsrepublic_post_meta_nonce' ] ) || !wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['newsrepublic_post_meta_nonce'] ) ), basename( __FILE__ ) ) ){

            return;

        }

        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ){

            return;

        }
            
        if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {  

            if ( !current_user_can( 'edit_page', $post_id ) ){  

                return $post_id;

            }

        }elseif( !current_user_can( 'edit_post', $post_id ) ) {

            return $post_id;

        }


        foreach ( $newsrepublic_post_sidebar_fields as $newsrepublic_post_sidebar_field ) {  
            

                $old = esc_html( get_post_meta( $post_id, 'newsrepublic_post_sidebar_option', true ) ); 
                $new = isset( $_POST['newsrepublic_post_sidebar_option'] ) ? newsrepublic_sanitize_sidebar_option_meta( wp_unslash( $_POST['newsrepublic_post_sidebar_option'] ) ) : '';

                if ( $new && $new != $old ){

                    update_post_meta ( $post_id, 'newsrepublic_post_sidebar_option', $new );

                }elseif( '' == $new && $old ) {

                    delete_post_meta( $post_id,'newsrepublic_post_sidebar_option', $old );

                }

            
        }

        $twp_disable_ajax_load_next_post_old = esc_html( get_post_meta( $post_id, 'twp_disable_ajax_load_next_post', true ) ); 
        $twp_disable_ajax_load_next_post_new = isset( $_POST['twp_disable_ajax_load_next_post'] ) ? newsrepublic_sanitize_meta_pagination( wp_unslash( $_POST['twp_disable_ajax_load_next_post'] ) ) : '';

        if( $twp_disable_ajax_load_next_post_new && $twp_disable_ajax_load_next_post_new != $twp_disable_ajax_load_next_post_old ){

            update_post_meta ( $post_id, 'twp_disable_ajax_load_next_post', $twp_disable_ajax_load_next_post_new );

        }elseif( '' == $twp_disable_ajax_load_next_post_new && $twp_disable_ajax_load_next_post_old ) {

            delete_post_meta( $post_id,'twp_disable_ajax_load_next_post', $twp_disable_ajax_load_next_post_old );

        }


        foreach ( $newsrepublic_post_layout_options as $newsrepublic_post_layout_option ) {  
            
            $newsrepublic_post_layout_old = esc_html( get_post_meta( $post_id, 'newsrepublic_post_layout', true ) ); 
            $newsrepublic_post_layout_new = isset( $_POST['newsrepublic_post_layout'] ) ? newsrepublic_sanitize_post_layout_option_meta( wp_unslash( $_POST['newsrepublic_post_layout'] ) ) : '';

            if ( $newsrepublic_post_layout_new && $newsrepublic_post_layout_new != $newsrepublic_post_layout_old ){

                update_post_meta ( $post_id, 'newsrepublic_post_layout', $newsrepublic_post_layout_new );

            }elseif( '' == $newsrepublic_post_layout_new && $newsrepublic_post_layout_old ) {

                delete_post_meta( $post_id,'newsrepublic_post_layout', $newsrepublic_post_layout_old );

            }
            
        }



        foreach ( $newsrepublic_header_overlay_options as $newsrepublic_header_overlay_option ) {  
            
            $newsrepublic_header_overlay_old = esc_html( get_post_meta( $post_id, 'newsrepublic_header_overlay', true ) ); 
            $newsrepublic_header_overlay_new = isset( $_POST['newsrepublic_header_overlay'] ) ? newsrepublic_sanitize_header_overlay_option_meta( wp_unslash( $_POST['newsrepublic_header_overlay'] ) ) : '';

            if ( $newsrepublic_header_overlay_new && $newsrepublic_header_overlay_new != $newsrepublic_header_overlay_old ){

                update_post_meta ( $post_id, 'newsrepublic_header_overlay', $newsrepublic_header_overlay_new );

            }elseif( '' == $newsrepublic_header_overlay_new && $newsrepublic_header_overlay_old ) {

                delete_post_meta( $post_id,'newsrepublic_header_overlay', $newsrepublic_header_overlay_old );

            }
            
        }



        $newsrepublic_ed_feature_image_old = esc_html( get_post_meta( $post_id, 'newsrepublic_ed_feature_image', true ) ); 
        $newsrepublic_ed_feature_image_new = isset( $_POST['newsrepublic_ed_feature_image'] ) ? absint( wp_unslash( $_POST['newsrepublic_ed_feature_image'] ) ) : '';

        if ( $newsrepublic_ed_feature_image_new && $newsrepublic_ed_feature_image_new != $newsrepublic_ed_feature_image_old ){

            update_post_meta ( $post_id, 'newsrepublic_ed_feature_image', $newsrepublic_ed_feature_image_new );

        }elseif( '' == $newsrepublic_ed_feature_image_new && $newsrepublic_ed_feature_image_old ) {

            delete_post_meta( $post_id,'newsrepublic_ed_feature_image', $newsrepublic_ed_feature_image_old );

        }



        $newsrepublic_ed_post_views_old = esc_html( get_post_meta( $post_id, 'newsrepublic_ed_post_views', true ) ); 
        $newsrepublic_ed_post_views_new = isset( $_POST['newsrepublic_ed_post_views'] ) ? absint( wp_unslash( $_POST['newsrepublic_ed_post_views'] ) ) : '';

        if ( $newsrepublic_ed_post_views_new && $newsrepublic_ed_post_views_new != $newsrepublic_ed_post_views_old ){

            update_post_meta ( $post_id, 'newsrepublic_ed_post_views', $newsrepublic_ed_post_views_new );

        }elseif( '' == $newsrepublic_ed_post_views_new && $newsrepublic_ed_post_views_old ) {

            delete_post_meta( $post_id,'newsrepublic_ed_post_views', $newsrepublic_ed_post_views_old );

        }



        $newsrepublic_ed_post_read_time_old = esc_html( get_post_meta( $post_id, 'newsrepublic_ed_post_read_time', true ) ); 
        $newsrepublic_ed_post_read_time_new = isset( $_POST['newsrepublic_ed_post_read_time'] ) ? absint( wp_unslash( $_POST['newsrepublic_ed_post_read_time'] ) ) : '';

        if ( $newsrepublic_ed_post_read_time_new && $newsrepublic_ed_post_read_time_new != $newsrepublic_ed_post_read_time_old ){

            update_post_meta ( $post_id, 'newsrepublic_ed_post_read_time', $newsrepublic_ed_post_read_time_new );

        }elseif( '' == $newsrepublic_ed_post_read_time_new && $newsrepublic_ed_post_read_time_old ) {

            delete_post_meta( $post_id,'newsrepublic_ed_post_read_time', $newsrepublic_ed_post_read_time_old );

        }



        $newsrepublic_ed_post_like_dislike_old = esc_html( get_post_meta( $post_id, 'newsrepublic_ed_post_like_dislike', true ) ); 
        $newsrepublic_ed_post_like_dislike_new = isset( $_POST['newsrepublic_ed_post_like_dislike'] ) ? absint( wp_unslash( $_POST['newsrepublic_ed_post_like_dislike'] ) ) : '';

        if ( $newsrepublic_ed_post_like_dislike_new && $newsrepublic_ed_post_like_dislike_new != $newsrepublic_ed_post_like_dislike_old ){

            update_post_meta ( $post_id, 'newsrepublic_ed_post_like_dislike', $newsrepublic_ed_post_like_dislike_new );

        }elseif( '' == $newsrepublic_ed_post_like_dislike_new && $newsrepublic_ed_post_like_dislike_old ) {

            delete_post_meta( $post_id,'newsrepublic_ed_post_like_dislike', $newsrepublic_ed_post_like_dislike_old );

        }



        $newsrepublic_ed_post_author_box_old = esc_html( get_post_meta( $post_id, 'newsrepublic_ed_post_author_box', true ) ); 
        $newsrepublic_ed_post_author_box_new = isset( $_POST['newsrepublic_ed_post_author_box'] ) ? absint( wp_unslash( $_POST['newsrepublic_ed_post_author_box'] ) ) : '';

        if ( $newsrepublic_ed_post_author_box_new && $newsrepublic_ed_post_author_box_new != $newsrepublic_ed_post_author_box_old ){

            update_post_meta ( $post_id, 'newsrepublic_ed_post_author_box', $newsrepublic_ed_post_author_box_new );

        }elseif( '' == $newsrepublic_ed_post_author_box_new && $newsrepublic_ed_post_author_box_old ) {

            delete_post_meta( $post_id,'newsrepublic_ed_post_author_box', $newsrepublic_ed_post_author_box_old );

        }



        $newsrepublic_ed_post_social_share_old = esc_html( get_post_meta( $post_id, 'newsrepublic_ed_post_social_share', true ) ); 
        $newsrepublic_ed_post_social_share_new = isset( $_POST['newsrepublic_ed_post_social_share'] ) ? absint( wp_unslash( $_POST['newsrepublic_ed_post_social_share'] ) ) : '';

        if ( $newsrepublic_ed_post_social_share_new && $newsrepublic_ed_post_social_share_new != $newsrepublic_ed_post_social_share_old ){

            update_post_meta ( $post_id, 'newsrepublic_ed_post_social_share', $newsrepublic_ed_post_social_share_new );

        }elseif( '' == $newsrepublic_ed_post_social_share_new && $newsrepublic_ed_post_social_share_old ) {

            delete_post_meta( $post_id,'newsrepublic_ed_post_social_share', $newsrepublic_ed_post_social_share_old );

        }



        $newsrepublic_ed_post_reaction_old = esc_html( get_post_meta( $post_id, 'newsrepublic_ed_post_reaction', true ) ); 
        $newsrepublic_ed_post_reaction_new = isset( $_POST['newsrepublic_ed_post_reaction'] ) ? absint( wp_unslash( $_POST['newsrepublic_ed_post_reaction'] ) ) : '';

        if ( $newsrepublic_ed_post_reaction_new && $newsrepublic_ed_post_reaction_new != $newsrepublic_ed_post_reaction_old ){

            update_post_meta ( $post_id, 'newsrepublic_ed_post_reaction', $newsrepublic_ed_post_reaction_new );

        }elseif( '' == $newsrepublic_ed_post_reaction_new && $newsrepublic_ed_post_reaction_old ) {

            delete_post_meta( $post_id,'newsrepublic_ed_post_reaction', $newsrepublic_ed_post_reaction_old );

        }



        $newsrepublic_ed_post_rating_old = esc_html( get_post_meta( $post_id, 'newsrepublic_ed_post_rating', true ) ); 
        $newsrepublic_ed_post_rating_new = isset( $_POST['newsrepublic_ed_post_rating'] ) ? absint( wp_unslash( $_POST['newsrepublic_ed_post_rating'] ) ) : '';

        if ( $newsrepublic_ed_post_rating_new && $newsrepublic_ed_post_rating_new != $newsrepublic_ed_post_rating_old ){

            update_post_meta ( $post_id, 'newsrepublic_ed_post_rating', $newsrepublic_ed_post_rating_new );

        }elseif( '' == $newsrepublic_ed_post_rating_new && $newsrepublic_ed_post_rating_old ) {

            delete_post_meta( $post_id,'newsrepublic_ed_post_rating', $newsrepublic_ed_post_rating_old );

        }

        foreach ( $newsrepublic_page_layout_options as $newsrepublic_post_layout_option ) {  
        
            $newsrepublic_page_layout_old = sanitize_text_field( get_post_meta( $post_id, 'newsrepublic_page_layout', true ) ); 
            $newsrepublic_page_layout_new = isset( $_POST['newsrepublic_page_layout'] ) ? newsrepublic_sanitize_post_layout_option_meta( wp_unslash( $_POST['newsrepublic_page_layout'] ) ) : '';

            if ( $newsrepublic_page_layout_new && $newsrepublic_page_layout_new != $newsrepublic_page_layout_old ){

                update_post_meta ( $post_id, 'newsrepublic_page_layout', $newsrepublic_page_layout_new );

            }elseif( '' == $newsrepublic_page_layout_new && $newsrepublic_page_layout_old ) {

                delete_post_meta( $post_id,'newsrepublic_page_layout', $newsrepublic_page_layout_old );

            }
            
        }

        $newsrepublic_ed_header_overlay_old = absint( get_post_meta( $post_id, 'newsrepublic_ed_header_overlay', true ) ); 
        $newsrepublic_ed_header_overlay_new = isset( $_POST['newsrepublic_ed_header_overlay'] ) ? absint( wp_unslash( $_POST['newsrepublic_ed_header_overlay'] ) ) : '';

        if ( $newsrepublic_ed_header_overlay_new && $newsrepublic_ed_header_overlay_new != $newsrepublic_ed_header_overlay_old ){

            update_post_meta ( $post_id, 'newsrepublic_ed_header_overlay', $newsrepublic_ed_header_overlay_new );

        }elseif( '' == $newsrepublic_ed_header_overlay_new && $newsrepublic_ed_header_overlay_old ) {

            delete_post_meta( $post_id,'newsrepublic_ed_header_overlay', $newsrepublic_ed_header_overlay_old );

        }

    }

endif;   